@@ -5,7 +5,7 @@ BEGIN {
 # ABSTRACT: A bundle of MIDI and music modules
 use strict;
 use warnings;
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 1;
 
 __END__
@@ -20,7 +20,7 @@ Task::MusicBundle - A bundle of MIDI and music modules
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -98,12 +98,16 @@ L<Music::Gestalt> - Jul 13, 2005
 
 L<Music::Harmonics> - May 11, 2005
 
+L<Music::Interval::Barycentric>
+
 L<Music::Intervals>
 
 L<Music::LilyPondUtil>
 
 L<Music::NeoRiemannianTonnetz>
 
+L<Music::Note::Frequency>
+
 L<Music::Note::Role::Operators>
 
 L<Music::PitchNum>
